==> ilias-3.9.6.tbz: www/ilias/Services/Feeds/classes/class.ilUserFeedWriter.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

include_once("./Services/News/classes/class.ilNewsItem.php");
include_once("./Services/Feeds/classes/class.ilFeedItem.php");
include_once("./Services/Feeds/classes/class.ilFeedWriter.php");

/** @defgroup ServicesFeeds Services/Feeds
 */

/**
* Feed writer for personal user feeds.
*
* @author Alex Killing <alex.killing@gmx.de>
* @version $Id$
* @ingroup ServicesFeeds
*/
class ilUserFeedWriter extends ilFeedWriter
{
	
	function ilUserFeedWriter($a_user_id, $a_hash)
	{
		global $ilSetting, $lng;
		
		parent::ilFeedWriter();
		
		//$lng->loadLanguageModule("news");
		
		if ($a_user_id == "" || $a_hash == "")
		{
			return;
		}
		
		$news_set = new ilSetting("news");
		if (!$news_set->get("enable_rss_for_internal"))
		{
			return;
		}

		$hash = ilObjUser::_lookupFeedHash($a_user_id);
		
		include_once("./Services/News/classes/class.ilNewsItem.php");
		$rss_period = ilNewsItem::_lookupRSSPeriod();

		if ($a_hash == $hash)
		{
			$items = ilNewsItem::_getNewsItemsOfUser($a_user_id, true, true, $rss_period);
			if ($ilSetting->get('short_inst_name') != "")
			{
				$this->setChannelTitle($ilSetting->get('short_inst_name'));
			}
			else
			{
				$this->setChannelTitle("ILIAS");
			}

			$this->setChannelAbout(ILIAS_HTTP_PATH);
			$this->setChannelLink(ILIAS_HTTP_PATH);
			//$this->setChannelDescription("ILIAS Channel Description");
			$i = 0;
			foreach($items as $item)
			{
				$obj_id = ilObject::_lookupObjId($item["ref_id"]);
				$obj_type = ilObject::_lookupType($obj_id);
				$obj_title = ilObject::_lookupTitle($obj_id);

				// not nice, to do: general solution
				if ($obj_type == "mcst")
				{
					include_once("./Modules/MediaCast/classes/class.ilObjMediaCastAccess.php");
					if (!ilObjMediaCastAccess::_lookupOnline($obj_id))
					{
						continue;
					}
				}

				$i++;
				$feed_item = new ilFeedItem();
				$title = ilNewsItem::determineNewsTitle
					($item["context_obj_type"], $item["title"], $item["content_is_lang_var"],
					$item["agg_ref_id"], $item["aggregation"]);

				// path
				$cont_loc = new ilLocatorGUI();
				$cont_loc->addContextItems($item["ref_id"], true);
				$cont_loc->setTextOnly(true);
				$loc = "[".$cont_loc->getHTML()."]";
				
				// title
				$feed_item->setTitle($loc." ".$obj_title.": ".$this->prepareStr(str_replace("<br />", " ", $title)));
								
				// description
				$content = $this->prepareStr($item["content"]);
				$feed_item->setDescription($content);
				$feed_item->setLink(ILIAS_HTTP_PATH."/goto.php?client_id=".CLIENT_ID.
					"&amp;target=".$item["context_obj_type"]."_".$item["ref_id"]);
				$feed_item->setAbout($feed_item->getLink()."&amp;il_about_feed=".$item["id"]);
				$this->addItem($feed_item);
			}
		}
	}
}
?>

==> ilias-3.10.14.tbz: www/ilias/Services/Feeds/classes/class.ilUserFeedWriter.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

include_once("./Services/News/classes/class.ilNewsItem.php");
include_once("./Services/Feeds/classes/class.ilFeedItem.php");
include_once("./Services/Feeds/classes/class.ilFeedWriter.php");

/** @defgroup ServicesFeeds Services/Feeds
 */

/**
* Feed writer for personal user feeds.
*
* @author Alex Killing <alex.killing@gmx.de>
* @version $Id$
* @ingroup ServicesFeeds
*/
class ilUserFeedWriter extends ilFeedWriter
{
	
	function ilUserFeedWriter($a_user_id, $a_hash, $privFeed = false)
	{
		global $ilSetting, $lng;

		parent::ilFeedWriter();
		
		//$lng->loadLanguageModule("news");
		
		if ($a_user_id == "" || $a_hash == "")
		{
			return;
		}
		
		$news_set = new ilSetting("news");
		if (!$news_set->get("enable_rss_for_internal"))
		{
			return;
		}

		$hash = ilObjUser::_lookupFeedHash($a_user_id);
		
		include_once("./Services/News/classes/class.ilNewsItem.php");
		$rss_period = ilNewsItem::_lookupRSSPeriod();

		if ($a_hash == $hash)
		{
			if ($privFeed) 
			{
				ilNewsItem::setPrivateFeedId($a_user_id);
			}
			$items = ilNewsItem::_getNewsItemsOfUser($a_user_id, true, true, $rss_period);
			if ($ilSetting->get('short_inst_name') != "")
			{
				$this->setChannelTitle($ilSetting->get('short_inst_name'));
			}
			else
			{
				$this->setChannelTitle("ILIAS");
			}

			$this->setChannelAbout(ILIAS_HTTP_PATH);
			$this->setChannelLink(ILIAS_HTTP_PATH);
			//$this->setChannelDescription("ILIAS Channel Description");
			$i = 0;
			foreach($items as $item)
			{
				$obj_id = ilObject::_lookupObjId($item["ref_id"]);
				$obj_type = ilObject::_lookupType($obj_id);
				$obj_title = ilObject::_lookupTitle($obj_id);

				// not nice, to do: general solution
				if ($obj_type == "mcst")
				{
					include_once("./Modules/MediaCast/classes/class.ilObjMediaCastAccess.php");
					if (!ilObjMediaCastAccess::_lookupOnline($obj_id))
					{
						continue;
					}
				}

				$i++;
				$feed_item = new ilFeedItem();
				$title = ilNewsItem::determineNewsTitle
					($item["context_obj_type"], $item["title"], $item["content_is_lang_var"],
					$item["agg_ref_id"], $item["aggregation"]);

				// path
				$cont_loc = new ilLocatorGUI();
				$cont_loc->addContextItems($item["ref_id"], true);
				$cont_loc->setTextOnly(true);
				$loc = "[".$cont_loc->getHTML()."]";
				
				// title
				$feed_item->setTitle($this->prepareStr($loc)." ".$this->prepareStr($obj_title).": ".$this->prepareStr(str_replace("<br />", " ", $title)));
								
				// description
				$content = $this->prepareStr(nl2br($item["content"]));
				$feed_item->setDescription($content);
				$feed_item->setLink(ILIAS_HTTP_PATH."/goto.php?client_id=".CLIENT_ID.
					"&amp;target=".$item["context_obj_type"]."_".$item["ref_id"]);
				$feed_item->setAbout($feed_item->getLink()."&amp;il_about_feed=".$item["id"]);
				$this->addItem($feed_item);
			}
		}
	}
}
?>
